const PASSWORD_CID = "@mozilla.org/passwordmanager;1";
const PREF_CID = "@mozilla.org/preferences;1";
const STRINGBUNDLE_CID = "@mozilla.org/intl/stringbundle;1";

var gPasswordManager;
var gPasswordManagerInternal;

function getPasswordManager() {
  if (!gPasswordManager) {
    try {
      gPasswordManager = Components.classes[PASSWORD_CID].getService();
      gPasswordManager = gPasswordManager.QueryInterface(
        Components.interfaces.nsIPasswordManager);
    } catch (e) {
      reminderFox_logMessageLevel("getPasswordManager() failed: " + e.name  +  " -- " + e.message, REMINDER_FOX_LOG_LEVEL_INFO);
      
    }
  }
  return gPasswordManager;
}

function getPasswordManagerInternal() {
  if (!gPasswordManagerInternal) {
    try {
      gPasswordManagerInternal =
        Components.classes[PASSWORD_CID].getService();
      gPasswordManagerInternal = gPasswordManagerInternal.QueryInterface(
        Components.interfaces.nsIPasswordManagerInternal);
    } catch (e) {
         reminderFox_logMessageLevel("getPasswordManagerInternal() failed: " + e.name  +  " -- " + e.message, REMINDER_FOX_LOG_LEVEL_INFO);
    }
  }

  return gPasswordManagerInternal;
}

function getPassword(loginData) {
  if (!loginData) {
    return null;
   }

  var pmInternal = getPasswordManagerInternal();
  if (!pmInternal) {
    return null;
   }

  var host = {value:''};
  var user = {value:''};
  var password = {value:''};

  try {
    pmInternal.findPasswordEntry(loginData.ljURL, '', '',
      host, user, password);
    loginData.username = user.value;
    loginData.password = password.value;
    return loginData;
  } catch(e) {
        reminderFox_logMessageLevel("findPasswordEntry() failed: " + e.name  +  " -- " + e.message, REMINDER_FOX_LOG_LEVEL_INFO);
  }
  return null;
}

function savePassword(loginData) {
  if (!loginData || !loginData.ljURL || !loginData.username)
    return false;

  var pm = getPasswordManager();

  if (!pm)
    return false;

  try {
    pm.removeUser(loginData.ljURL, loginData.username);
  } catch(e) {
  	 reminderFox_logMessageLevel("removeUser() failed: " + e.name  +  " -- " + e.message, REMINDER_FOX_LOG_LEVEL_INFO);
  }

  if (loginData.savePassword) {
    try {
      pm.addUser(loginData.ljURL, loginData.username, loginData.password);
    } catch(e) {
    	 reminderFox_logMessageLevel("addUser failed: " + e.name  +  " -- " + e.message, REMINDER_FOX_LOG_LEVEL_INFO);
    }


    return true;
  }
  
  return false;
}

/*
  var loginData = {
    ljURL : getPref().CopyCharPref(LJ_URL_PREF),
    username : '',
    password : ''
  };
 */
